@@ -9,8 +9,9 @@ import urlparse
 import glob
 import re
 import subprocess
-from lockfile import FileLock, AlreadyLocked
+import bibos_client.bibos_proxy_setup
 
+from lockfile import FileLock, AlreadyLocked
 from bibos_utils.bibos_config import BibOSConfig
 
 from admin_client import BibOSAdmin
@@ -149,7 +150,7 @@ class LocalJob(dict):
     def save_property_to_file(self, prop, file_path):
         if(prop in self):
             fh = open(file_path, 'w')
-            fh.write(self[prop])
+            fh.write(self[prop].encode("utf8"))
             fh.close()
 
     def populate(self, data):
